@@ -76,7 +76,7 @@ class Alarm(HomeAssistant):
 
     def __init__(self, *args, entity_id: str = "system", **kwargs):
         self.domain = "alarm_control_panel"
-        super().__init__(entity_id=entity_id * args, **kwargs)
+        super().__init__(entity_id=entity_id, *args, **kwargs)
 
     def arm(self):
         """Arm alarm panel"""
@@ -126,12 +126,5 @@ class TaylorSwiftly:
 
 
 if __name__ == "__main__":
-    # test = InputBoolean("testing")
-    # print(test.status)
-    taylor_lock = Lock("taylor_swiftly_doors", location="home")
-    taylor_batt = Sensor("taylor_swiftly_battery", location="home")
-    # taylor.lock()
-    taylor = TaylorSwiftly()
-    # taylor.get_functions()["lock lock"]()
-    print(taylor.get_functions())
-    print(taylor.battery.s)
+    alarm = Alarm()
+    print(alarm.status())
